<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:output method="html" omit-xml-declaration="yes" encoding="UTF-8" indent="yes" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>

  <xsl:template match="*"/>

  <xsl:template match="svn">
    <html xml:lang="en" lang="en">
<!-- <html xml:lang="bg" lang="bg">  target language -->
      <head>
        <title>
          <xsl:if test="string-length(index/@name) != 0">
            <xsl:value-of select="index/@name"/>
            <xsl:text> : </xsl:text>
          </xsl:if>
          <xsl:value-of select="index/@path"/>
          <xsl:text> | version: </xsl:text>
          <xsl:value-of select="index/@rev"/>
        </title>
        <link rel="stylesheet" type="text/css" href="/xslt/ash.css"/>
	<!--<style type="text/css" media="all">@import "/ash.css";</style> -->
      </head>
      <body>
        <div id="svn">
          <xsl:apply-templates/>
        </div>
        <div id="footer">
          <xsl:text>Based on </xsl:text>
          <!-- Some link to the hosting machine -->
          <xsl:element name="a">
            <xsl:attribute name="href">http://127.0.0.1</xsl:attribute>
            <xsl:text>Spaska</xsl:text>
          </xsl:element>
          <xsl:text> </xsl:text>
          <xsl:element name="a">
            <xsl:attribute name="href">
              <xsl:value-of select="@href"/>
            </xsl:attribute>
            <xsl:text>Subversion</xsl:text>
          </xsl:element>
          <xsl:text> </xsl:text>
          <xsl:value-of select="@version"/>
          <a href="http://www.w3.org/">
            <img src="/xslt/valid-xhtml10.png" alt="Valid XHTML 1.0!"/>
          </a>
        </div>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="index">
    <div id="rev">
      <xsl:if test="string-length(@name) != 0">
        <xsl:value-of select="@name"/>
        <xsl:if test="string-length(@rev) != 0">
          <xsl:text> &#8212; </xsl:text>
        </xsl:if>
      </xsl:if>
      <xsl:if test="string-length(@rev) != 0">
        <xsl:text>Version </xsl:text>
        <xsl:value-of select="@rev"/>
      </xsl:if>
    </div>
    <ul id="paths">
      <xsl:call-template name="pathchain">
        <xsl:with-param name="dirs" select="/svn/index/@path"/>
      </xsl:call-template>
    </ul>
    <div id="divider"/>
    <div id="content">
      <ul>
        <li id="dirtitle">Directories</li>
        <xsl:apply-templates select="dir"/>
        <li id="filetitle">Files</li>
        <xsl:apply-templates select="file"/>
      </ul>
    </div>
  </xsl:template>

  <xsl:template name="pathchain">
    <!-- Makes a <li></li>-delimited chain of paths.
         Used with the /svn/index/@path attribute -->
    <xsl:param name="dirs"/>
    <xsl:choose>
      <!-- do nothing in case of zero length arg -->
      <xsl:when test="string-length($dirs)=0"></xsl:when>
      <xsl:otherwise>
        <!-- arg OK, let's transform -->
        <xsl:choose>
          <xsl:when test="not(contains($dirs,'/'))">
            <!-- The final element of the path - the current dir -->
            <xsl:element name="li">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:text>.</xsl:text>
                </xsl:attribute>
                <xsl:value-of select="$dirs"/>
                <xsl:text>/</xsl:text>
              </xsl:element>
            </xsl:element>
          </xsl:when>
          <xsl:when test="starts-with($dirs,'/')">
            <!-- The top dir -->
            <xsl:element name="li">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:call-template name="dotchain">
                    <xsl:with-param name="updirs">
                      <xsl:value-of select="$dirs"/>
                    </xsl:with-param>
                  </xsl:call-template>
                </xsl:attribute>
                <xsl:text>/</xsl:text>
              </xsl:element>
            </xsl:element>
            <xsl:call-template name="pathchain">
              <xsl:with-param name="dirs">
                <xsl:value-of select="substring-after($dirs,'/')"/>
              </xsl:with-param>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <!-- Must be part of the chain of paths -->
            <xsl:element name="li">
              <xsl:element name="a">
                <xsl:attribute name="href">
                  <xsl:call-template name="dotchain">
                    <xsl:with-param name="updirs">
                      <xsl:value-of select="$dirs"/>
                    </xsl:with-param>
                  </xsl:call-template>
                </xsl:attribute>
                <xsl:value-of select="substring-before($dirs,'/')"/>
                <xsl:text>/</xsl:text>
              </xsl:element>
            </xsl:element>
            <xsl:call-template name="pathchain">
              <xsl:with-param name="dirs">
                <xsl:value-of select="substring-after($dirs,'/')"/>
              </xsl:with-param>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="dotchain">
    <!-- makes ../ chains of dots and slashes -->
    <xsl:param name="updirs"/>
    <xsl:if test="contains($updirs,'/')">
      <xsl:text>../</xsl:text>
      <xsl:call-template name="dotchain">
        <xsl:with-param name="updirs">
          <xsl:value-of select="substring-after($updirs,'/')"/>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template match="dir">
    <li class="dir">
      <xsl:element name="a">
        <xsl:attribute name="href">
          <xsl:value-of select="@href"/>
        </xsl:attribute>
        <xsl:value-of select="@name"/>
        <xsl:text>/</xsl:text>
      </xsl:element>
    </li>
    <!-- <xsl:apply-templates/ -->
  </xsl:template>

  <xsl:template match="file">
    <li class="file">
      <xsl:element name="a">
        <xsl:attribute name="href">
          <xsl:value-of select="@href"/>
        </xsl:attribute>
        <xsl:value-of select="@name"/>
      </xsl:element>
    </li>
    <!-- xsl:apply-templates/ -->
  </xsl:template>

</xsl:stylesheet>
